@@ -6,12 +6,12 @@
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Library General Public License for more details.
 #
-# You should have received a copy of the GNU Library General 
-# Public License along with this library; if not, write to the 
-# Free Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+# You should have received a copy of the GNU Library General
+# Public License along with this library; if not, write to the
+# Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
 
@@ -19,7 +19,7 @@
 # FUNCTION:            DESCRIPTION:
 #  gldFit               Fits parameters of a GLD
 #  .gldFit.mle          Fits parameters of a GLD using maximum log-likelihood
-#  .gldFit.mps          Fits parameters of a GLD using maximum product spacings 
+#  .gldFit.mps          Fits parameters of a GLD using maximum product spacings
 #  .gldFit.gof          Fits parameters of a GLD using GoF Statistics
 #   .ksGLD               Kolmogorov Smirnov Statistics
 #   .cvmGLD              Cramer von Mise Statistics
@@ -28,12 +28,12 @@
 #   type="fd"            Freedman-Diaconis binning
 #   type="scott"         Scott binning
 #   type="sturges"       Sturges binning
-#  .gldFit.rob          Fits parameters of a GLD using robust moments fit  
+#  .gldFit.rob          Fits parameters of a GLD using robust moments fit
 ################################################################################
 
 
 gldFit <-
-function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8, 
+function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     method = c("mle", "mps", "gof", "hist", "rob"),
     scale = NA, doplot = TRUE, add = FALSE, span = "auto", trace = TRUE,
     title = NULL, description = NULL, ...)
@@ -41,73 +41,73 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Fits parameters of a GLD using maximum log-likelihood  
-    
+    #   Fits parameters of a GLD using maximum log-likelihood
+
     # Arguments:
     #   lambda1 - a numeric value, the location parameter
     #   lambda2 - a numeric value, the scale parameter
     #   lambda3 - a numeric value, the first shape parameter
     #   lambda4 - a numeric value, the second parameter
-    
+
     # Note:
-    #   The GLD uses RS parameterization and parameters in Region 4, 
+    #   The GLD uses RS parameterization and parameters in Region 4,
     #   i.e. lambda[3,4]<0, lambda2<0
-    
-    # FUNCTION:  
-    
+
+    # FUNCTION:
+
     # Check Parameters:
     stopifnot(lambda2 < 0)
     stopifnot(lambda3 < 0)
     stopifnot(lambda4 < 0)
-    
+
     # Settings:
     method = match.arg(method)
-    
+
     # Parameter Fit:
-    if (method == "mle") { 
-        ans = .gldFit.mle(x, lambda1, lambda2, lambda3, lambda4, 
-            scale, doplot, add, span, trace, title, description, ...) 
+    if (method == "mle") {
+        ans = .gldFit.mle(x, lambda1, lambda2, lambda3, lambda4,
+            scale, doplot, add, span, trace, title, description, ...)
     } else if (method == "mps") {
-        ans = .gldFit.mps(x, lambda1, lambda2, lambda3, lambda4, 
-            scale, doplot, add, span, trace, title, description, ...) 
+        ans = .gldFit.mps(x, lambda1, lambda2, lambda3, lambda4,
+            scale, doplot, add, span, trace, title, description, ...)
     } else if (method == "gof") {
-        ans = .gldFit.gof(x, lambda1, lambda2, lambda3, lambda4, 
-            scale, doplot, add, span, trace, title, description, ...) 
+        ans = .gldFit.gof(x, lambda1, lambda2, lambda3, lambda4,
+            scale, doplot, add, span, trace, title, description, ...)
     } else if (method == "hist") {
-        ans = .gldFit.hist(x, lambda1, lambda2, lambda3, lambda4, 
-            scale, doplot, add, span, trace, title, description, ...) 
+        ans = .gldFit.hist(x, lambda1, lambda2, lambda3, lambda4,
+            scale, doplot, add, span, trace, title, description, ...)
     } else if (method == "rob") {
-        ans = .gldFit.rob (x, lambda1, lambda2, lambda3, lambda4, 
-            scale, doplot, add, span, trace, title, description, ...) 
+        ans = .gldFit.rob (x, lambda1, lambda2, lambda3, lambda4,
+            scale, doplot, add, span, trace, title, description, ...)
     }
-       
+
     # Return Value:
     ans
 }
-   
+
 
 # ------------------------------------------------------------------------------
 
 
 .gldFit.mle <-
-function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8, 
+function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     scale = NA, doplot = TRUE, add = FALSE, span = "auto", trace = TRUE,
     title = NULL, description = NULL, ...)
 {
     # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Fits parameters of a GLD using maximum log-likelihood  
+    #   Fits parameters of a GLD using maximum log-likelihood
 
     # Example:
     #   require(fBasics)
     #   set.seed(4711); x=rgld(5000); fit=gldFit.mle(x)@fit$estimate; fit
-    
+
     # FUNCTION:
 
     # Settings:
     scale = FALSE
-    
+
     # Transform:
     x.orig = x
     x = as.vector(x)
@@ -121,7 +121,7 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     # Objective Function:
     obj <- function(x, y = x, trace) {
         DGLD = try(dgld(y, x[1], x[2], x[3], x[4]), silent = TRUE)
-        if (class(DGLD) == "try-error") return(1e9) 
+        if (class(DGLD) == "try-error") return(1e9)
         f = -sum(log(DGLD))
         # Print Iteration Path:
         if (trace) {
@@ -129,16 +129,16 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
             cat("\n Parameter Estimates:       ", x[1], x[2], x[3], x[4], "\n")
         }
         f }
-        
+
     # Parameter Estimation:
     eps = 1e-10
     BIG = 100
     r = nlminb(
-        start = c(lambda1, lambda2, lambda3, lambda4), 
+        start = c(lambda1, lambda2, lambda3, lambda4),
         objective = obj,
-        lower = c(-BIG, -BIG, -BIG, -BIG), 
-        upper = c(+BIG, -eps, -eps, -eps), 
-        y = x, 
+        lower = c(-BIG, -BIG, -BIG, -BIG),
+        upper = c(+BIG, -eps, -eps, -eps),
+        y = x,
         trace = trace)
     names(r$par) <- c("lambda1", "lambda2", "lambda3", "lambda4")
 
@@ -187,7 +187,7 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
 
 
 .gldFit.mps <-
-function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8, 
+function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     type = c("sum", "mean", "max", "median", "var"),
     scale = NA, doplot = TRUE, add = FALSE, span = "auto", trace = TRUE,
     title = NULL, description = NULL, ...)
@@ -195,60 +195,60 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Fits parameters of a GLD using maximum product spacings  
+    #   Fits parameters of a GLD using maximum product spacings
 
     # Example:
     #   require(fBasics)
     #   set.seed(4711); x=rgld(5000); fit=.gldFit.mps(x)@fit$estimate; fit
-    
+
     # FUNCTION:
 
     # Settings:
     scale = FALSE
     type = match.arg(type)
     CALL = match.call()
-    
+
     # Transform:
     x.orig = x
     x = as.vector(x)
     if (scale) {
         SD = sd(x)
-        x = x / SD }  
+        x = x / SD }
 
     # Objective Function:
     TYPE = toupper(type)
     if(type == "sum") {
-        typeFun = sum 
+        typeFun = sum
     } else if (type == "mean") {
-        typeFun = mean 
+        typeFun = mean
     } else if (type == "median") {
-        typeFun = median 
+        typeFun = median
     } else if (type == "max") {
         typeFun = function(x) -max(x)
     } else if (type == "var") {
         typeFun = function(x) -var(x) }
-    obj = function(x, y = x, typeFun, trace) { 
+    obj = function(x, y = x, typeFun, trace) {
         PGLD = try(pgld(sort(y), x[1], x[2], x[3], x[4]), silent = TRUE)
-        if (class(PGLD) == "try-error") return(1e9) 
+        if (class(PGLD) == "try-error") return(1e9)
         DH = diff(c(0, na.omit(PGLD), 1))
         f = try(-typeFun(log(DH[DH > 0])), silent = TRUE)
-        if (class(PGLD) == "try-error") return(1e9) 
+        if (class(PGLD) == "try-error") return(1e9)
         # Print Iteration Path:
         if (trace) {
             cat("\n Objective Function Value:  ", f)
             cat("\n Parameter Estimates:       ", x[1], x[2], x[3], x[4], "\n")
         }
         f }
-        
+
     # Parameter Estimation:
     eps = 1e-10
     BIG = 100
     r = nlminb(
-        start = c(lambda1, lambda2, lambda3, lambda4), 
+        start = c(lambda1, lambda2, lambda3, lambda4),
         objective = obj,
-        lower = c(-BIG, -BIG, -BIG, -BIG), 
-        upper = c(+BIG, -eps, -eps, -eps), 
-        y = x, 
+        lower = c(-BIG, -BIG, -BIG, -BIG),
+        upper = c(+BIG, -eps, -eps, -eps),
+        y = x,
         typeFun = typeFun,
         trace = trace)
     names(r$par) <- c("lambda1", "lambda2", "lambda3", "lambda4")
@@ -297,27 +297,27 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
 # ------------------------------------------------------------------------------
 
 
-.ksGLD <- 
+.ksGLD <-
 function(N, PFGL) {
     D = 1/(2*N)  + max ( abs( PFGL - ((1:N)-0.5)/N ) )
     D }
-    
-.cvmGLD <- 
+
+.cvmGLD <-
 function(N, PFGL) {
     W2 = 1/(12*N)  + sum ( PFGL - ((1:N)-0.5)/N  )^2
-    W2 } 
-       
-.adGLD <- 
+    W2 }
+
+.adGLD <-
 function(N, PFGL) {
     A2 = -N -(1/N) * sum( (2*(1:N)-1) * ( log(PFGL) + log(1-rev(PFGL)) ) )
-    A2 }        
-     
-    
-# ------------------------------------------------------------------------------   
+    A2 }
+
+
+# ------------------------------------------------------------------------------
 
 
 .gldFit.gof <-
-function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8, 
+function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     type = c("ad", "ks", "cvm"),
     scale = NA, doplot = TRUE, add = FALSE, span = "auto", trace = TRUE,
     title = NULL, description = NULL, ...)
@@ -325,19 +325,19 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Fits parameters of a GLD using GoF Statistics  
+    #   Fits parameters of a GLD using GoF Statistics
 
     # Example:
     #   require(fBasics)
     #   set.seed(4711); x=rgld(5000); fit=.gldFit.gof(x)@fit$estimate; fit
-    
+
     # FUNCTION:
 
     # Settings:
     scale = FALSE
     type = match.arg(type)
     CALL = match.call()
-    
+
     # Transform:
     x.orig = x
     x = as.vector(x)
@@ -347,7 +347,9 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
 
     # Objective Function:
     TYPE = toupper(type)
-    typeFun <- match.fun(paste(".", type, sep = ""))
+    ## DJS 20/02/2010
+    ## typeFun <- match.fun(paste(".", type, sep = ""))
+    typeFun <- match.fun(paste(".", type, "GLD", sep = ""))
     obj = function(x, y = x, typeFun, trace) {
         PFGL = try(pgld(sort(y), x[1], x[2], x[3], x[4]), silent = TRUE)
         if (class(PFGL) == "try-error") return(1e9)
@@ -362,15 +364,15 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
             cat("\n Parameter Estimates:       ", x[1], x[2], x[3], x[4],"\n")
         }
         f }
-        
+
     # Parameter Estimation:
     eps = 1e-10
     BIG = 100
     r = nlminb(
-        start = c(lambda1, lambda2, lambda3, lambda4), 
+        start = c(lambda1, lambda2, lambda3, lambda4),
         objective = obj,
-        lower = c(-BIG, -BIG, -BIG, -BIG), 
-        upper = c(+BIG, -eps, -eps, -eps), 
+        lower = c(-BIG, -BIG, -BIG, -BIG),
+        upper = c(+BIG, -eps, -eps, -eps),
         y = x,
         typeFun = typeFun,
         trace = trace)
@@ -421,7 +423,7 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
 
 
 .gldFit.hist <-
-function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8, 
+function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     type = c("fd", "sturges", "scott"),
     scale = NA, doplot = TRUE, add = FALSE, span = "auto", trace = TRUE,
     title = NULL, description = NULL, ...)
@@ -429,12 +431,12 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Fits parameters of a GLD using a histogram fit  
+    #   Fits parameters of a GLD using a histogram fit
 
     # Example:
     #   require(fBasics)
     #   set.seed(4711); x=rgld(5000); fit=gldFit.hist(x)@fit$estimate; fit
-    
+
     # FUNCTION:
 
     # Settings:
@@ -444,7 +446,7 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     if (type == "fd") type = "FD"
     else if (type == "scott") type = "Scott"
     else if (type == "sturges") type = "Sturges"
-    
+
     # Transform:
     x.orig = x
     x = as.vector(x)
@@ -467,15 +469,15 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
             cat("\n Parameter Estimates:       ", x[1], x[2], x[3], x[4], "\n")
         }
         f }
-        
+
     # Parameter Estimation:
     eps = 1e-10
     BIG = 100
     r = nlminb(
-        start = c(lambda1, lambda2, lambda3, lambda4), 
+        start = c(lambda1, lambda2, lambda3, lambda4),
         objective = obj,
-        lower = c(-BIG, -BIG, -BIG, -BIG), 
-        upper = c(+BIG, -eps, -eps, -eps), 
+        lower = c(-BIG, -BIG, -BIG, -BIG),
+        upper = c(+BIG, -eps, -eps, -eps),
         hist = HIST,
         trace = trace)
     names(r$par) <- c("lambda1", "lambda2", "lambda3", "lambda4")
@@ -525,24 +527,24 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
 
 
 .gldFit.rob <-
-function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8, 
+function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
     scale = NA, doplot = TRUE, add = FALSE, span = "auto", trace = TRUE,
     title = NULL, description = NULL, ...)
 {
     # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Fits parameters of a GLD using robust moments (quantile) fit  
+    #   Fits parameters of a GLD using robust moments (quantile) fit
 
     # Example:
     #   require(fBasics)
     #   set.seed(4711); x=rgld(5000); fit=.gldFit.rob(x)@fit$estimate; fit
-    
+
     # FUNCTION:
 
     # Settings:
     scale = FALSE
-    
+
     # Transform:
     x.orig = x
     x = as.vector(x)
@@ -579,19 +581,19 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
         }
         f
     }
-  
+
     # Parameter Estimation:
     eps = 1e-10
     BIG = 100
     r = nlminb(
-        start = c(lambda1, lambda2, lambda3, lambda4), 
+        start = c(lambda1, lambda2, lambda3, lambda4),
         objective = obj,
-        lower = c(-BIG, -BIG, -BIG, -BIG), 
-        upper = c(+BIG, -eps, -eps, -eps), 
+        lower = c(-BIG, -BIG, -BIG, -BIG),
+        upper = c(+BIG, -eps, -eps, -eps),
         xMED = xMED, xIQR = xIQR, xSKEW = xSKEW, xKURT = xKURT,
         trace = trace)
     names(r$par) <- c("lambda1", "lambda2", "lambda3", "lambda4")
-    
+
     # Add Title and Description:
     if (is.null(title)) title = "GLD Region 4 Robust Moment Estimation"
     if (is.null(description)) description = description()
@@ -634,4 +636,4 @@ function(x, lambda1 = 0, lambda2 = -1, lambda3 = -1/8, lambda4 = -1/8,
 
 
 ################################################################################
-    
+
